@@ -87,7 +87,7 @@ private:
 	P array[SIZE];
 	P* current;
 public:
-	inline SMPile() {current=array-1;}
+	inline SMPile() {current=array;}
 
 	inline P top() {return *current;}
 	inline P pop() {return *(current--);}
